Printer class

Constructors

Printer({required String url, required String name, String? model, String? location, String? comment, required bool isDefault, required bool isAvailable, required int state})

Properties

comment → String?
A user comment about the printer.
final
hashCode → int
The hash code for this object.
no setterinherited
isAvailable → bool
Whether the printer is available for printing (e.g., not offline or stopped).
final
isDefault → bool
Whether this is the default printer on the system.
final
location → String?
The physical location of the printer.
final
model → String?
The printer model.
final
name → String
The display name of the printer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → int
The raw platform-specific state value.
final
url → String
The platform specific printer identification (e.g., device URI).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited