WindowsPaperSize class

Represents a paper size supported by a Windows printer.

Constructors

WindowsPaperSize({required String name, required int id, required double widthMillimeters, required double heightMillimeters})

Properties

hashCode → int
The hash code for this object.
no setterinherited
heightMillimeters → double
final
id → int
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widthMillimeters → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited