WindowsPrinterCapabilitiesModel class

Holds the capabilities (paper sizes, resolutions) of a Windows printer.

Constructors

WindowsPrinterCapabilitiesModel({required List<WindowsPaperSize> paperSizes, required List<WindowsPaperSource> paperSources, required List<WindowsResolution> resolutions, required List<WindowsMediaType> mediaTypes, required bool isColorSupported, required bool isMonochromeSupported, required bool supportsLandscape})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isColorSupported → bool
final
isMonochromeSupported → bool
final
mediaTypes → List<WindowsMediaType>
final
paperSizes → List<WindowsPaperSize>
final
paperSources → List<WindowsPaperSource>
final
resolutions → List<WindowsResolution>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsLandscape → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited