PrintJobsRequest class

These classes are not part of the public API but need to be accessible by the test file for mocking isolate communication.

Annotations

Constructors

PrintJobsRequest(int id, String printerName)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
printerName String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited