SubmitPdfJobRequest class

Annotations

Constructors

SubmitPdfJobRequest(int id, String printerName, String pdfFilePath, String docName, Map<String, String>? options, int scalingMode, int copies, String? pageRange, String alignment)
const

Properties

alignment String
finalinherited
copies int
finalinherited
docName String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
options Map<String, String>?
finalinherited
pageRange String?
finalinherited
pdfFilePath String
finalinherited
printerName String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalingMode int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited